@@ -131,7 +131,7 @@ class LMScript(BaseSerializable):
         novel_params=[],
         command_params=[[]],
         commands=[],
-        **kwargs
+        **kwargs,
     ):
         if version < MIN_LSB_VERSION or version > MAX_LSB_VERSION:
             logger.warning("LSB compilation unsupported for LMScript version {}".format(version))
@@ -268,7 +268,8 @@ class LMScript(BaseSerializable):
             "param_stream_size" / construct.Int32ul,
             "command_params"
             / construct.Array(
-                construct.this.command_count, _ParamStreamAdapter(construct.Bytes(construct.this.param_stream_size)),
+                construct.this.command_count,
+                _ParamStreamAdapter(construct.Bytes(construct.this.param_stream_size)),
             ),
             "commands" / construct.PrefixedArray(construct.Int32ul, construct.Select(*_command_structs)),
         )
